// Unit tests are small and more focused, testing one module in isolation
// Integration tests are entirely external and use code in the same
// way that any other external code would, using only the public
// interface and potentially exercising mutliple modules per test
//
// For unit tests, convention is to create a module in each file
// named tests for the test functions and annotate the module
// with cfg(test). Integration tests don't get this
//
// For the integration tests section, go back to the adder folder
// https://rust-book.cs.brown.edu/ch11-03-test-organization.html#integration-tests

pub fn add(left: u64, right: u64) -> u64 {
    left + right
}

// Can test internal functions
fn internal_adder(left: usize, right: usize) -> usize {
    left + right
}

#[cfg(test)]
mod tests {
    use super::*;

    #[test]
    fn it_works() {
        let result = add(2, 2);
        assert_eq!(result, 4);
    }

    #[test]
    fn internal() {
        let result = internal_adder(2, 2);
        assert_eq!(result, 4);
    }
}
